@@ -1,5 +1,6 @@
 import nwborglab
 import os
+from os.path import expanduser
 from datetime import datetime as dt
 from SAPOFTO import SAPOFTO
 
@@ -53,7 +54,8 @@ def init(args):
         print('First nwborglab initialization! Setting up... ')
         with open('/'.join(nwborglab.__file__.split('/')[:-1]) + '/' + '.nwborglabsrc.org', 'r') as f: # TODO replace this with where the package will be
             content = f.read()
-        with open('~/.nwborglabsrc.org', 'w') as f: # TODO replace this with where the package will be
+        home = expanduser("~")
+        with open(os.path.join(home,'.nwborglabsrc.org'), 'w') as f: # TODO replace this with where the package will be
             f.write(content)
 
     if os.path.isfile('.nwborglab.org'):
