@@ -1,6 +1,6 @@
 from nwborglab import subjectHandler
 import os
-import SAPOFTO
+from SAPOFTO import SAPOFTO
 import orgutils
 from datetime import datetime as dt
 
